# $Id$

use strict;
use warnings;

use Test::More tests => 29;
use File::Temp qw(tempdir);
use POSIX qw(strftime);

use_ok('ObsData');

ok(my $o = ObsData->new('testdata/obsdata-conftest', logfile => "testdata/obsdata.log"), "Can create object");

# Log level testing
ok(ObsData::loglevel(0) eq "DEBUG", "Can get loglevel");
ok(ObsData::loglevel(10) eq "?????", "Can get wrong loglevel");
ok($o->loglevel(0) eq "DEBUG", "Can get loglevel");
ok($o->loglevel(10) eq "?????", "Can get wrong loglevel");
ok($o->logging(0, "FOO%s", "FOO") eq "FOOFOO", "logging properly return the message");

ok($o->load, "can load repository");
ok($o->is_obs('ohp'), "Isobs works");
ok(!$o->is_obs('ozone'), "Isobs works");
ok($o->getvalue('ohp', 'description'), "can get value");
ok($o->config_mtime > 0, "Can get mtime of config file");
ok($o->config_mtime > 0, "Can get mtime a second time of config file");

ok(eq_set([ $o->list_obs ], [ 'ohp' ]), "Can list observatories");

ok($o->is_obs('ohp'), "check is an obs is defined");
ok(!$o->is_obs('NOohp'), "check is an obs is not defined");

{
my %datadir =  $o->list_obsdatadir('ohp');
ok($datadir{ozone} eq 'testdata/ohp/ozone', "Can get list of data directory");
}

ok(eq_set([ $o->list_typedatadir('ozone') ], [ 'testdata/ohp/ozone', 'testdata/ohp' ]) , 'Can list data directory');
ok(eq_set([ $o->get_datadir('ohp', 'ozone') ], [ 'testdata/ohp/ozone', 'testdata/ohp' ]) , 'Can retrive data directory');
ok(eq_set([ $o->list_datatype ], [ 'oxygene', 'ozone' ]), "can get data type");
print STDERR join(" ", $o->list_datatype);

# Testing match rules
ok($o->match_data_type('ozone', 'ozone12'), "String matching setting");
ok(!$o->match_data_type('ozone', 'foo12'), "String no matching setting");

ok($o->find_match_data_type('ozone12'), "is able to find good datatype");
ok(!$o->find_match_data_type('foo12'), "is able to find good datatype");

ok(
    eq_array( 
        [ $o->build_dest_filename('ozone12') ], 
        [ 'ozone', '12/dest12' ]
    ), 
    "Can build dest string"
);
ok(
    eq_array(
        [ $o->build_dest_filename('ozone12', 'ozone') ],
        [ 'ozone', '12/dest12' ]
    ),
    "Can build dest string with datatype"
);
ok(
    eq_array(
        [ $o->build_dest_filename('oxygene12', 'oxygene') ],
        [ 'oxygene', strftime("%Y/dest12/oxygene12", gmtime) ]
    ),
    "Can build dest string with datatype"
);
ok(!defined($o->build_dest_filename('foo12')), "Return undef if no match");
ok(!defined($o->build_dest_filename('ozone12', 'oxygene')), "Return undef if no match");

$o = undef; # Explicit destroy
